@@ -117,19 +117,19 @@ class Client(object):
             raise APIError(resp.text, resp.status_code)
         return resp.json()
 
-    def analyze_image(self, path, params={}):
-        url = '{}/analysis/{}'.format(config.API_URL, path)
-        resp = requests.get(url, auth=self.auth)
-        if resp.status_code != 200:
-            raise APIError(resp.text, resp.status_code)
-        resp = resp.json()
-        if resp.get('salmap'):
-            resp['salmap'] = BytesIO(base64.b64decode(resp['salmap'][23:]))
-        return resp
+    # def analyze_image(self, path, params={}):
+    #     url = '{}/analysis/{}'.format(config.API_URL, path)
+    #     resp = requests.get(url, auth=self.auth)
+    #     if resp.status_code != 200:
+    #         raise APIError(resp.text, resp.status_code)
+    #     resp = resp.json()
+    #     if resp.get('salmap'):
+    #         resp['salmap'] = BytesIO(base64.b64decode(resp['salmap'][23:]))
+    #     return resp
 
     def detect_labels(self, path, params={}):
         url = '{}/rekognition/{}'.format(config.API_URL, path)
-        resp = requests.get(url, auth=self.auth)
+        resp = requests.get(url, params=params, auth=self.auth)
         if resp.status_code != 200:
             raise APIError(resp.text, resp.status_code)
         return resp.json()
@@ -146,13 +146,6 @@ class Client(object):
             raise APIError(resp.text, resp.status_code)
         return BytesIO(resp.content)
 
-    def transform_video(self, path, params={}):
-        url = '{}/videos/{}'.format(config.API_URL, path)
-        resp = requests.get(url, params=params, auth=self.auth)
-        if resp.status_code != 200:
-            raise APIError(resp.text, resp.status_code)
-        return resp.json()
-
 
 class Abraia(Client):
     def __init__(self, folder=''):
@@ -197,40 +190,9 @@ class Abraia(Client):
         f = self.remove_file(self.userid + '/' + path)
         return {'path': f['source'][length:]}
 
-    def from_file(self, file):
-        resp = self.upload_file(file, self.userid + '/' + self.folder)
-        self.path = resp['source']
-        self.params = {'q': 'auto'}
-        return self
-
-    def from_url(self, url):
-        resp = self.upload_remote(url, self.userid + '/' + self.folder)
-        self.path = resp['source']
-        self.params = {'q': 'auto'}
-        return self
-
-    def from_store(self, path):
-        self.path = self.userid + '/' + path
-        self.params = {}
-        return self
-
-    def to_file(self, filename):
-        ext = filename.split('.').pop().lower()
-        self.params['format'] = self.params.get('format') or ext
-        buffer = self.transform_image(self.path, self.params)
-        with open(filename, 'wb') as f:
+    def transform(self, path, dest, params={'quality': 'auto'}):
+        ext = dest.split('.').pop().lower()
+        params['format'] = self.params.get('format') or ext
+        buffer = self.transform_image(self.userid + '/' + path, params=params)
+        with open(dest, 'wb') as f:
             f.write(buffer.getvalue())
-        return self
-
-    def resize(self, width=None, height=None, mode=None):
-        if width:
-            self.params['width'] = width
-        if height:
-            self.params['height'] = height
-        if mode:
-            self.params['mode'] = mode
-        return self
-
-    def process(self, params={}):
-        self.params.update(params)
-        return self
